@@ -21,7 +21,7 @@
 
 #include <QObject>
 
-#include <qtest.h>
+#include <QTest>
 
 using namespace Akonadi;
 
