@@ -26,10 +26,9 @@
 #include "krandom.h"
 
 #include <QMimeDatabase>
-#include <QMimeType>
 
 
-#include <qtest.h>
+#include <QTest>
 
 QTEST_MAIN(MimeTypeCheckerTest)
 
