@@ -37,7 +37,7 @@ class FakeClient : public QThread
 
 public:
     explicit FakeClient(QObject *parent = nullptr);
-    ~FakeClient();
+    ~FakeClient() override;
 
     void setScenarios(const TestScenario::List &scenarios);
 
@@ -47,7 +47,7 @@ protected:
     void run() override;
 
 private Q_SLOTS:
-    void dataAvailable();
+    bool dataAvailable();
     void readServerPart();
     void writeClientPart();
     void connectionLost();
