@@ -39,12 +39,7 @@ class ItemMoveHandlerTest : public QObject
 public:
     ItemMoveHandlerTest()
     {
-        try {
-            FakeAkonadiServer::instance()->init();
-        } catch (const FakeAkonadiServerException &e) {
-            qWarning() << "Server exception: " << e.what();
-            qFatal("Fake Akonadi Server failed to start up, aborting test");
-        }
+        FakeAkonadiServer::instance()->init();
     }
 
     ~ItemMoveHandlerTest()
