@@ -203,14 +203,9 @@ public:
     ItemRetrieverTest()
         : QObject()
     {
-        try {
-            FakeAkonadiServer::instance()->setPopulateDb(false);
-            FakeAkonadiServer::instance()->disableItemRetrievalManager();
-            FakeAkonadiServer::instance()->init();
-        } catch (const FakeAkonadiServerException &e) {
-            qWarning() << "Server exception: " << e.what();
-            qFatal("Fake Akonadi Server failed to start up, aborting test");
-        }
+        FakeAkonadiServer::instance()->setPopulateDb(false);
+        FakeAkonadiServer::instance()->disableItemRetrievalManager();
+        FakeAkonadiServer::instance()->init();
     }
 
     ~ItemRetrieverTest()
