@@ -43,7 +43,7 @@ class AgentBasePrivate : public QObject
 
 public:
     explicit AgentBasePrivate(AgentBase *parent);
-    virtual ~AgentBasePrivate();
+    ~AgentBasePrivate() override;
     void init();
     virtual void delayedInit();
 
@@ -92,7 +92,7 @@ public:
     int mStatusCode;
     QString mStatusMessage;
 
-    uint mProgress;
+    int mProgress;
     QString mProgressMessage;
 
     bool mNeedsNetwork;
