@@ -66,7 +66,6 @@ class ResourceBasePrivate;
  * - a .desktop file similar to the following example
  *   \code
  * [Desktop Entry]
- * Encoding=UTF-8
  * Name=My Akonadi Resource
  * Type=AkonadiResource
  * Exec=akonadi_my_resource
@@ -188,13 +187,13 @@ public:
         QApplication app(argc, argv);
         debugAgent(argc, argv);
         const QString id = parseArguments(argc, argv);
-        T *r = new T(id);
+        T r(id);
 
         // check if T also inherits AgentBase::Observer and
         // if it does, automatically register it on itself
-        Observer *observer = dynamic_cast<Observer *>(r);
+        Observer *observer = dynamic_cast<Observer *>(&r);
         if (observer != nullptr) {
-            r->registerObserver(observer);
+            r.registerObserver(observer);
         }
 
         return init(r);
@@ -336,7 +335,7 @@ protected Q_SLOTS:
     void setItemSyncBatchSize(int batchSize);
 
     /**
-     * Set to true to scheudle an attribute sync before every item sync.
+     * Set to true to schedule an attribute sync before every item sync.
      * The default is false.
      *
      * @since 4.15
@@ -364,7 +363,7 @@ protected Q_SLOTS:
      * when delivering the result instead of creating new items to ensure conflict
      * detection will work.
      * @param parts The item parts that should be retrieved.
-     * @return false if there is an immeidate error when retrieving the items.
+     * @return false if there is an immediate error when retrieving the items.
      * @see itemsRetrieved()
      * @since 5.4
      *
@@ -843,7 +842,7 @@ protected:
 
 private:
     static QString parseArguments(int argc, char **argv);
-    static int init(ResourceBase *r);
+    static int init(ResourceBase &r);
 
     // dbus resource interface
     friend class ::Akonadi__ResourceAdaptor;
