@@ -172,7 +172,7 @@ void ResourceScheduler::scheduleItemsFetch(const Item::List &items, const QSet<Q
     for (const auto &item : items) {
         ids.push_back(QString::number(item.id()));
     }
-    signalTaskToTracker(t, "FetchItems", ids.join(QStringLiteral(", ")));
+    signalTaskToTracker(t, "FetchItems", ids.join(QLatin1String(", ")));
     scheduleNext();
 }
 
@@ -529,7 +529,7 @@ void ResourceScheduler::signalTaskToTracker(const Task &task, const QByteArray &
     if (!s_resourcetracker) {
         const QString suffix = Akonadi::Instance::identifier().isEmpty() ? QString() : QLatin1Char('-') + Akonadi::Instance::identifier();
         if (KDBusConnectionPool::threadConnection().interface()->isServiceRegistered(QStringLiteral("org.kde.akonadiconsole") + suffix)) {
-            s_resourcetracker = new QDBusInterface(QStringLiteral("org.kde.akonadiconsole") + suffix,
+            s_resourcetracker = new QDBusInterface(QLatin1String("org.kde.akonadiconsole") + suffix,
                                                    QStringLiteral("/resourcesJobtracker"),
                                                    QStringLiteral("org.freedesktop.Akonadi.JobTracker"),
                                                    KDBusConnectionPool::threadConnection(), nullptr);
@@ -685,7 +685,7 @@ QTextStream &Akonadi::operator<<(QTextStream &d, const ResourceScheduler::Task &
             for (const auto &item : qAsConst(task.items)) {
                 ids.push_back(QString::number(item.id()));
             }
-            d << "items " << ids.join(QStringLiteral(", ")) << " ";
+            d << "items " << ids.join(QLatin1String(", ")) << " ";
         }
         if (!task.methodName.isEmpty()) {
             d << task.methodName << " " << task.argument.toString();
