@@ -32,7 +32,8 @@
 #include "controlmanagerinterface.h"
 #include "janitorinterface.h"
 #include "akonadistarter.h"
-#include "akonadi_version.h"
+#include "akonadifull-version.h"
+
 
 #include <private/protocol_p.h>
 #include <private/dbus_p.h>
@@ -115,7 +116,7 @@ static bool checkSearchSupportStatus()
     }
 
     // There's always at least server-search available
-    std::cerr << "Akonadi Server Search Support: available (" << searchMethods.join(QStringLiteral(", ")).toStdString() << ")" << std::endl;
+    std::cerr << "Akonadi Server Search Support: available (" << searchMethods.join(QLatin1String(", ")).toStdString() << ")" << std::endl;
     return true;
 }
 
@@ -141,7 +142,7 @@ static bool checkAvailableAgentTypes()
     if (types.isEmpty()) {
         std::cerr << "No agent types found!" << std::endl;
     } else {
-        std::cerr << types.join(QStringLiteral(", ")).toStdString() << std::endl;
+        std::cerr << types.join(QLatin1String(", ")).toStdString() << std::endl;
     }
 
     return true;
@@ -234,7 +235,7 @@ int main(int argc, char **argv)
 
     KAboutData aboutData(QStringLiteral("akonadictl"),
                          QStringLiteral("akonadictl"),
-                         QStringLiteral(AKONADI_VERSION_STRING),
+                         QStringLiteral(AKONADI_FULL_VERSION),
                          QStringLiteral("akonadictl"),
                          KAboutLicense::LGPL_V2);
     KAboutData::setApplicationData(aboutData);
