@@ -25,6 +25,7 @@
 
 #include <QObject>
 #include <KSharedConfig>
+#include <QDialogButtonBox>
 
 class KAboutData;
 
@@ -91,7 +92,7 @@ public:
      *
      * Subclasses must provide a constructor with this exact signature.
      */
-    explicit AgentConfigurationBase(KSharedConfigPtr config, QWidget *parentWidget,
+    explicit AgentConfigurationBase(const KSharedConfigPtr &config, QWidget *parentWidget,
                                     const QVariantList &args);
 
     ~AgentConfigurationBase() override;
@@ -126,6 +127,18 @@ public:
      */
     KAboutData *aboutData() const;
 
+    /**
+     * Reimplement to restore dialog size.
+     */
+    virtual QSize restoreDialogSize() const;
+
+    /**
+     * Reimplement to save dialog size.
+     */
+    virtual void saveDialogSize(const QSize &size);
+
+    virtual QDialogButtonBox::StandardButtons standardButtons() const;
+
 protected:
     QWidget *parentWidget() const;
 
@@ -145,6 +158,9 @@ protected:
      */
     void setKAboutData(const KAboutData &aboutData);
 
+Q_SIGNALS:
+    void enableOkButton(bool enabled);
+
 private:
     class Private;
     friend class Private;
