@@ -97,15 +97,25 @@ void AttributeStorage::clearAttributes()
     mModifiedAttributes.clear();
 }
 
-Attribute *AttributeStorage::attribute(const QByteArray &type) const
+const Attribute *AttributeStorage::attribute(const QByteArray &type) const
 {
     return mAttributes.value(type);
 }
 
+Attribute *AttributeStorage::attribute(const QByteArray &type)
+{
+    Attribute *attr = mAttributes.value(type);
+    if (attr)
+        markAttributeModified(type);
+    return attr;
+}
+
 void AttributeStorage::markAttributeModified(const QByteArray &type)
 {
-    mDeletedAttributes.remove(type);
-    mModifiedAttributes.insert(type);
+    if (mAttributes.contains(type)) {
+        mDeletedAttributes.remove(type);
+        mModifiedAttributes.insert(type);
+    }
 }
 
 void AttributeStorage::resetChangeLog()
