@@ -619,7 +619,7 @@ static QString format_types(const PayloadContainer &c)
     for (PayloadContainer::const_iterator it = c.begin(), end = c.end(); it != end; ++it) {
         result.push_back(format_type(it->sharedPointerId, it->metaTypeId));
     }
-    return result.join(QStringLiteral(", "));
+    return result.join(QLatin1String(", "));
 }
 
 #if 0
