@@ -243,7 +243,7 @@ public:
 
     /**
      * Returns the parent collection of this object.
-     * @note This will of course only return a useful value if it was explictely retrieved
+     * @note This will of course only return a useful value if it was explicitly retrieved
      *       from the Akonadi server.
      * @since 4.4
      */
@@ -251,7 +251,7 @@ public:
 
     /**
      * Returns a reference to the parent collection of this object.
-     * @note This will of course only return a useful value if it was explictely retrieved
+     * @note This will of course only return a useful value if it was explicitly retrieved
      *       from the Akonadi server.
      * @since 4.4
      */
@@ -293,6 +293,10 @@ public:
 
     /**
      * Returns a list of all attributes of the item.
+     *
+     * @warning Do not modify the attributes returned from this method,
+     * the change will not be reflected when updating the Item through
+     * ItemModifyJob.
      */
     Attribute::List attributes() const;
 
@@ -304,13 +308,15 @@ public:
     /**
      * Returns the attribute of the given type @p name if available, 0 otherwise.
      */
-    Attribute *attribute(const QByteArray &name) const;
+    Attribute *attribute(const QByteArray &name);
+    const Attribute *attribute(const QByteArray &name) const;
 
     /**
      * Describes the options that can be passed to access attributes.
      */
     enum CreateOption {
-        AddIfMissing    ///< Creates the attribute if it is missing
+        AddIfMissing,   ///< Creates the attribute if it is missing
+        DontCreate      ///< Do not create the attribute if it is missing (default)
     };
 
     /**
@@ -321,13 +327,13 @@ public:
      * @param option The create options.
      */
     template <typename T>
-    inline T *attribute(CreateOption option);
+    inline T *attribute(CreateOption option = DontCreate);
 
     /**
      * Returns the attribute of the requested type or 0 if it is not available.
      */
     template <typename T>
-    inline T *attribute() const;
+    inline const T *attribute() const;
 
     /**
      * Removes and deletes the attribute of the requested type.
@@ -577,6 +583,7 @@ public:
 // We know that auto_ptr is deprecated, but we still want to handle the case
 // without compilers yelling at us all the time just because item.h gets included
 // virtually everywhere
+#if __cplusplus < 201703L
 #ifdef __GNUC__
 #ifdef __clang__
 #pragma clang diagnostic push
@@ -593,6 +600,7 @@ public:
 #else
 #pragma GCC diagnostic pop
 #endif
+#endif
 #endif
     template <typename T> void setPayload(std::unique_ptr<T> p);
     //@endcond
@@ -785,35 +793,31 @@ AKONADICORE_EXPORT uint qHash(const Akonadi::Item &item);
 template <typename T>
 inline T *Item::attribute(Item::CreateOption option)
 {
-    Q_UNUSED(option);
-
-    const T dummy;
-    if (hasAttribute(dummy.type())) {
-        T *attr = dynamic_cast<T *>(attribute(dummy.type()));
-        if (attr) {
+    const QByteArray type = T().type();
+    if (hasAttribute(type)) {
+        if (T *attr = dynamic_cast<T *>(attribute(type))) {
             return attr;
         }
-        //Reuse 5250
-        qWarning() << "Found attribute of unknown type" << dummy.type()
+        qWarning() << "Found attribute of unknown type" << type
                    << ". Did you forget to call AttributeFactory::registerAttribute()?";
+    } else if (option == AddIfMissing) {
+        T *attr = new T();
+        addAttribute(attr);
+        return attr;
     }
 
-    T *attr = new T();
-    addAttribute(attr);
-    return attr;
+    return nullptr;
 }
 
 template <typename T>
-inline T *Item::attribute() const
+inline const T *Item::attribute() const
 {
-    const T dummy;
-    if (hasAttribute(dummy.type())) {
-        T *attr = dynamic_cast<T *>(attribute(dummy.type()));
-        if (attr) {
+    const QByteArray type = T().type();
+    if (hasAttribute(type)) {
+        if (const T *attr = dynamic_cast<const T *>(attribute(type))) {
             return attr;
         }
-        //reuse 5250
-        qWarning() << "Found attribute of unknown type" << dummy.type()
+        qWarning() << "Found attribute of unknown type" << type
                    << ". Did you forget to call AttributeFactory::registerAttribute()?";
     }
 
@@ -823,15 +827,13 @@ inline T *Item::attribute() const
 template <typename T>
 inline void Item::removeAttribute()
 {
-    const T dummy;
-    removeAttribute(dummy.type());
+    removeAttribute(T().type());
 }
 
 template <typename T>
 inline bool Item::hasAttribute() const
 {
-    const T dummy;
-    return hasAttribute(dummy.type());
+    return hasAttribute(T().type());
 }
 
 template <typename T>
@@ -1040,6 +1042,7 @@ void Item::setPayload(T *p)
     p->You_MUST_NOT_use_a_pointer_as_payload;
 }
 
+#if __cplusplus < 201703L
 #ifdef __GNUC__
 #ifdef __clang__
 #pragma clang diagnostic push
@@ -1061,6 +1064,7 @@ void Item::setPayload(std::auto_ptr<T> p)
 #pragma GCC diagnostic pop
 #endif
 #endif
+#endif
 
 template <typename T>
 void Item::setPayload(std::unique_ptr<T> p)
