@@ -228,7 +228,7 @@ struct TypedPayload {
     int metaTypeId;
 };
 
-struct BySharedPointerAndMetaTypeID : std::unary_function<TypedPayload, bool> {
+struct BySharedPointerAndMetaTypeID {
     const int spid;
     const int mtid;
     BySharedPointerAndMetaTypeID(int spid, int mtid)
@@ -265,17 +265,13 @@ namespace Akonadi
 typedef std::vector<_detail::TypedPayload> PayloadContainer;
 }
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 9, 0) // see qtbase e5e2629
 namespace QtPrivate {
-#endif
 // disable Q_FOREACH on PayloadContainer (b/c it likes to take copies and clone_ptr doesn't like that)
 template <>
 class QForeachContainer<Akonadi::PayloadContainer>
 {
 };
-#if QT_VERSION >= QT_VERSION_CHECK(5, 9, 0)
 }
-#endif
 
 namespace Akonadi
 {
@@ -312,9 +308,6 @@ public:
         mRemoteId = other.mRemoteId;
         mRemoteRevision = other.mRemoteRevision;
         mPayloadPath = other.mPayloadPath;
-        Q_FOREACH (Attribute *attr, other.mAttributes) {
-            mAttributes.insert(attr->type(), attr->clone());
-        }
         if (other.mParent) {
             mParent = new Collection(*(other.mParent));
         }
@@ -342,15 +335,14 @@ public:
         changelog->deletedFlags(this) = changelog->deletedFlags(&other);
         changelog->addedTags(this) = changelog->addedTags(&other);
         changelog->deletedTags(this) = changelog->deletedTags(&other);
-        changelog->deletedAttributes(this) = changelog->deletedAttributes(&other);
+        changelog->attributeStorage(this) = changelog->attributeStorage(&other);
     }
 
     ~ItemPrivate()
     {
-        qDeleteAll(mAttributes);
         delete mParent;
 
-        ItemChangeLog::instance()->clearItemChangelog(this);
+        ItemChangeLog::instance()->removeItem(this);
     }
 
     void resetChangeLog()
@@ -444,7 +436,6 @@ public:
     QString mRemoteId;
     QString mRemoteRevision;
     mutable QString mPayloadPath;
-    QHash<QByteArray, Attribute *> mAttributes;
     mutable Collection *mParent;
     mutable _detail::clone_ptr<Internal::PayloadBase> mLegacyPayload;
     mutable PayloadContainer mPayloads;
