@@ -97,7 +97,20 @@ void ItemFetchScope::fetchAllAttributes(bool fetch)
 
 bool ItemFetchScope::isEmpty() const
 {
-    return d->mPayloadParts.isEmpty() && d->mAttributes.isEmpty() && !d->mFullPayload && !d->mAllAttributes && !d->mFetchTags && !d->mFetchVRefs;
+    return d->mPayloadParts.isEmpty()
+        && d->mAttributes.isEmpty()
+        && !d->mFullPayload
+        && !d->mAllAttributes
+        && !d->mCacheOnly
+        && !d->mCheckCachedPayloadPartsOnly
+        && d->mFetchMtime // true by deafult -> false = non-empty
+        && !d->mIgnoreRetrievalErrors
+        && d->mFetchRid // true by default
+        && !d->mFetchGid
+        && !d->mFetchTags
+        && !d->mFetchVRefs
+        && !d->mFetchRelations
+        && d->mAncestorDepth == AncestorRetrieval::None;
 }
 
 bool ItemFetchScope::cacheOnly() const
