@@ -91,11 +91,11 @@ public:
      *                   the selection.
      * @param parent The parent object.
      */
-    explicit ResourceSelectJob(const QString &identifier, QObject *parent = 0);
+    explicit ResourceSelectJob(const QString &identifier, QObject *parent = nullptr);
 
 protected:
-    void doStart() Q_DECL_OVERRIDE;
-    bool doHandleResponse(qint64 tag, const Protocol::Command &response) Q_DECL_OVERRIDE;
+    void doStart() override;
+    bool doHandleResponse(qint64 tag, const Protocol::CommandPtr &response) override;
 
 private:
     //@cond PRIVATE
