@@ -74,7 +74,7 @@ public:
     /**
      * Destroys the entity mime type filter model.
      */
-    virtual ~EntityMimeTypeFilterModel();
+    ~EntityMimeTypeFilterModel() override;
 
     /**
      * Add mime types to be shown by the filter.
@@ -107,12 +107,12 @@ public:
     /**
      * Returns the list of mime type inclusion filters.
      */
-    QStringList mimeTypeInclusionFilters() const;
+    Q_REQUIRED_RESULT QStringList mimeTypeInclusionFilters() const;
 
     /**
      * Returns the list of mime type exclusion filters.
      */
-    QStringList mimeTypeExclusionFilters() const;
+    Q_REQUIRED_RESULT QStringList mimeTypeExclusionFilters() const;
 
     /**
      * Clear all mime type filters.
@@ -128,13 +128,13 @@ public:
 
     QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override;
 
-    bool hasChildren(const QModelIndex &parent = QModelIndex()) const override;
+    Q_REQUIRED_RESULT bool hasChildren(const QModelIndex &parent = QModelIndex()) const override;
 
-    bool canFetchMore(const QModelIndex &parent) const override;
+    Q_REQUIRED_RESULT bool canFetchMore(const QModelIndex &parent) const override;
 
-    QModelIndexList match(const QModelIndex &start, int role, const QVariant &value, int hits = 1, Qt::MatchFlags flags = Qt::MatchFlags(Qt::MatchStartsWith | Qt::MatchWrap)) const override;
+    Q_REQUIRED_RESULT QModelIndexList match(const QModelIndex &start, int role, const QVariant &value, int hits = 1, Qt::MatchFlags flags = Qt::MatchFlags(Qt::MatchStartsWith | Qt::MatchWrap)) const override;
 
-    int columnCount(const QModelIndex &parent = QModelIndex()) const override;
+    Q_REQUIRED_RESULT int columnCount(const QModelIndex &parent = QModelIndex()) const override;
 
 protected:
     bool filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const override;
