@@ -114,15 +114,6 @@ void EntityTreeModel::setCollectionMonitored(const Collection &col, bool monitor
     d->m_monitor->setCollectionMonitored(col, monitored);
 }
 
-void EntityTreeModel::setCollectionReferenced(const Akonadi::Collection &col, bool referenced)
-{
-    Q_D(EntityTreeModel);
-    Akonadi::Collection referencedCollection = col;
-    referencedCollection.setReferenced(referenced);
-    //We have to use the same session as the monitor, so the monitor can fetch the collection afterwards
-    new Akonadi::CollectionModifyJob(referencedCollection, d->m_monitor->session());
-}
-
 bool EntityTreeModel::systemEntitiesShown() const
 {
     Q_D(const EntityTreeModel);
@@ -317,7 +308,7 @@ QVariant EntityTreeModel::data(const QModelIndex &index, int role) const
             return d->m_pendingCutCollections.contains(node->id);
         case Qt::BackgroundRole: {
             if (collection.hasAttribute<EntityDisplayAttribute>()) {
-                EntityDisplayAttribute *eda = collection.attribute<EntityDisplayAttribute>();
+                const EntityDisplayAttribute *eda = collection.attribute<EntityDisplayAttribute>();
                 QColor color = eda->backgroundColor();
                 if (color.isValid()) {
                     return color;
@@ -368,7 +359,7 @@ QVariant EntityTreeModel::data(const QModelIndex &index, int role) const
             return d->m_pendingCutItems.contains(node->id);
         case Qt::BackgroundRole: {
             if (item.hasAttribute<EntityDisplayAttribute>()) {
-                EntityDisplayAttribute *eda = item.attribute<EntityDisplayAttribute>();
+                const EntityDisplayAttribute *eda = item.attribute<EntityDisplayAttribute>();
                 const QColor color = eda->backgroundColor();
                 if (color.isValid()) {
                     return color;
