@@ -50,12 +50,14 @@
 
 #include <QMessageBox>
 #include <QIcon>
+#include <QElapsedTimer>
 
-QHash<KJob *, QTime> jobTimeTracker;
+QHash<KJob *, QElapsedTimer> jobTimeTracker;
 
 Q_LOGGING_CATEGORY(DebugETM, "org.kde.pim.akonadi.ETM", QtInfoMsg)
 
 using namespace Akonadi;
+using namespace AkRanges;
 
 static CollectionFetchJob::Type getFetchType(EntityTreeModel::CollectionFetchStrategy strategy)
 {
@@ -639,7 +641,7 @@ void EntityTreeModelPrivate::retrieveAncestors(const Akonadi::Collection &collec
         parentCollection = parentCollection.parentCollection();
     }
     Q_ASSERT(parentCollection.isValid());
-    // if m_rootCollection is Collection::root(), we always have common ancestor and do the retrival
+    // if m_rootCollection is Collection::root(), we always have common ancestor and do the retrieval
     // if we traversed up to Collection::root() but are looking at a subtree only (m_rootCollection != Collection::root())
     // we have no common ancestor, and we don't have to retrieve anything
     if (parentCollection == Collection::root() && m_rootCollection != Collection::root()) {
@@ -1351,7 +1353,7 @@ void EntityTreeModelPrivate::collectionFetchJobDone(KJob *job)
 
     if (!m_collectionTreeFetched && m_pendingCollectionFetchJobs.isEmpty()) {
         m_collectionTreeFetched = true;
-        Q_EMIT q_ptr->collectionTreeFetched(m_collections | values | toQVector);
+        Q_EMIT q_ptr->collectionTreeFetched(m_collections | Views::values | Actions::toQVector);
     }
 
     qCDebug(DebugETM) << "Fetch job took " << jobTimeTracker.take(job).elapsed() << "msec";
