@@ -38,6 +38,8 @@
 #include <utility>
 
 using namespace Akonadi;
+using namespace AkRanges;
+
 class operation;
 
 static const int PipelineSize = 5;
@@ -470,7 +472,7 @@ bool MonitorPrivate::ensureDataAvailable(const Protocol::ChangeNotificationPtr &
 
         // Make sure all tags for ModifyTags operation are in cache too
         if (itemNtf.operation() == Protocol::ItemChangeNotification::ModifyTags) {
-            if (!tagCache->ensureCached((itemNtf.addedTags() + itemNtf.removedTags()) | toQList, mTagFetchScope)) {
+            if (!tagCache->ensureCached((itemNtf.addedTags() + itemNtf.removedTags()) | Actions::toQList, mTagFetchScope)) {
                 return false;
             }
         }
@@ -952,7 +954,7 @@ void MonitorPrivate::slotNotify(const Protocol::ChangeNotificationPtr &msg)
                 }
             } else {
                 const Protocol::ChangeNotificationList split = splitMessage(itemNtf, !supportsBatch);
-                pendingNotifications << (split | toQList);
+                pendingNotifications << (split | Actions::toQList);
                 appendedMessages += split.count();
             }
         }
@@ -1047,8 +1049,8 @@ bool MonitorPrivate::emitItemsNotification(const Protocol::ItemChangeNotificatio
 
     Tag::List addedTags, removedTags;
     if (msg.operation() == Protocol::ItemChangeNotification::ModifyTags) {
-        addedTags = tagCache->retrieve(msg.addedTags() | toQList);
-        removedTags = tagCache->retrieve(msg.removedTags() | toQList);
+        addedTags = tagCache->retrieve(msg.addedTags() | Actions::toQList);
+        removedTags = tagCache->retrieve(msg.removedTags() | Actions::toQList);
     }
 
     Item::List its = items;
@@ -1084,7 +1086,7 @@ bool MonitorPrivate::emitItemsNotification(const Protocol::ItemChangeNotificatio
         handled |= emitToListeners(&Monitor::itemsUnlinked, its, col);
         return handled;
     case Protocol::ItemChangeNotification::ModifyTags:
-        return emitToListeners(&Monitor::itemsTagsChanged, its, addedTags | toQSet, removedTags | toQSet);
+        return emitToListeners(&Monitor::itemsTagsChanged, its, addedTags | Actions::toQSet, removedTags | Actions::toQSet);
     case Protocol::ItemChangeNotification::ModifyRelations:
         return emitToListeners(&Monitor::itemsRelationsChanged, its, addedRelations, removedRelations);
     default:
