@@ -18,6 +18,9 @@
 */
 
 #include "notificationsubscriber.h"
+#include "itemfetchscope.h"
+#include "collectionfetchscope.h"
+#include "tagfetchscope.h"
 
 namespace Akonadi
 {
@@ -41,6 +44,9 @@ public:
         , mimeTypes(other.mimeTypes)
         , resources(other.resources)
         , ignoredSessions(other.ignoredSessions)
+        , itemFetchScope(other.itemFetchScope)
+        , collectionFetchScope(other.collectionFetchScope)
+        , tagFetchScope(other.tagFetchScope)
         , isAllMonitored(other.isAllMonitored)
         , isExclusive(other.isExclusive)
     {}
@@ -54,6 +60,9 @@ public:
     QSet<QString> mimeTypes;
     QSet<QByteArray> resources;
     QSet<QByteArray> ignoredSessions;
+    ItemFetchScope itemFetchScope;
+    CollectionFetchScope collectionFetchScope;
+    TagFetchScope tagFetchScope;
     bool isAllMonitored;
     bool isExclusive;
 };
@@ -196,3 +205,33 @@ void NotificationSubscriber::setIsExclusive(bool isExclusive)
 {
     d->isExclusive = isExclusive;
 }
+
+ItemFetchScope NotificationSubscriber::itemFetchScope() const
+{
+    return d->itemFetchScope;
+}
+
+void NotificationSubscriber::setItemFetchScope(const ItemFetchScope &itemFetchScope)
+{
+    d->itemFetchScope = itemFetchScope;
+}
+
+CollectionFetchScope NotificationSubscriber::collectionFetchScope() const
+{
+    return d->collectionFetchScope;
+}
+
+void NotificationSubscriber::setCollectionFetchScope(const CollectionFetchScope &fetchScope)
+{
+    d->collectionFetchScope = fetchScope;
+}
+
+TagFetchScope NotificationSubscriber::tagFetchScope() const
+{
+    return d->tagFetchScope;
+}
+
+void NotificationSubscriber::setTagFetchScope(const TagFetchScope &tagFetchScope)
+{
+    d->tagFetchScope = tagFetchScope;
+}
