@@ -55,7 +55,7 @@ AKONADICORE_EXPORT bool canPaste(const QMimeData *mimeData, const Collection &co
   @param copy Indicate whether this is a copy or a move.
   @returns The job performing the paste, 0 if there is nothing to paste.
 */
-AKONADICORE_EXPORT KJob *paste(const QMimeData *mimeData, const Collection &collection, bool copy = true, Session *session = 0);
+AKONADICORE_EXPORT KJob *paste(const QMimeData *mimeData, const Collection &collection, bool copy = true, Session *session = nullptr);
 
 /**
   URI list paste/drop.
@@ -64,7 +64,7 @@ AKONADICORE_EXPORT KJob *paste(const QMimeData *mimeData, const Collection &coll
   @param action The drop action (copy/move/link).
   @returns The job performing the paste, 0 if there is nothing to paste.
 */
-AKONADICORE_EXPORT KJob *pasteUriList(const QMimeData *mimeData, const Collection &collection, Qt::DropAction action, Session *session = 0);
+AKONADICORE_EXPORT KJob *pasteUriList(const QMimeData *mimeData, const Collection &collection, Qt::DropAction action, Session *session = nullptr);
 }
 
 }
