@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2013-2017 Montel Laurent <montel@kde.org>
+    Copyright (c) 2013-2019 Montel Laurent <montel@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -31,7 +31,7 @@ class AKONADICORE_EXPORT Pop3ResourceAttribute : public Akonadi::Attribute
 {
 public:
     Pop3ResourceAttribute();
-    ~Pop3ResourceAttribute();
+    ~Pop3ResourceAttribute() override;
 
     /* reimpl */
     Pop3ResourceAttribute *clone() const override;
