@@ -49,9 +49,9 @@
         qputenv("LC_ALL", "C"); \
         qunsetenv("KDE_COLOR_DEBUG"); \
         QApplication app(argc, argv); \
-        app.setApplicationName(QLatin1String("qttest")); \
-        app.setOrganizationDomain(QLatin1String("kde.org")); \
-        app.setOrganizationName(QLatin1String("KDE")); \
+        app.setApplicationName(QStringLiteral("qttest")); \
+        app.setOrganizationDomain(QStringLiteral("kde.org")); \
+        app.setOrganizationName(QStringLiteral("KDE")); \
         QGuiApplication::setQuitOnLastWindowClosed(false); \
         qRegisterMetaType<QList<QUrl>>(); \
         int result = 0; \
@@ -71,12 +71,10 @@ namespace AkonadiTest
  */
 void checkTestIsIsolated()
 {
-    Q_ASSERT_X(!qEnvironmentVariableIsEmpty("TESTRUNNER_DB_ENVIRONMENT"),
-               "AkonadiTest::checkTestIsIsolated",
-               "This test must be run using ctest, in order to use the testrunner environment. Aborting, to avoid messing up your real akonadi");
-    Q_ASSERT_X(qgetenv("XDG_DATA_HOME").contains("testrunner"),
-               "AkonadiTest::checkTestIsIsolated",
-               "Did you forget to run the test using QTEST_AKONADIMAIN?");
+    if (qEnvironmentVariableIsEmpty("TESTRUNNER_DB_ENVIRONMENT"))
+        qFatal("This test must be run using ctest, in order to use the testrunner environment. Aborting, to avoid messing up your real akonadi");
+    if (!qgetenv("XDG_DATA_HOME").contains("testrunner"))
+        qFatal("Did you forget to run the test using QTEST_AKONADIMAIN?");
 }
 
 /**
@@ -85,7 +83,8 @@ void checkTestIsIsolated()
 void setAllResourcesOffline()
 {
     // switch all resources offline to reduce interference from them
-    Q_FOREACH (Akonadi::AgentInstance agent, Akonadi::AgentManager::self()->instances()) {    //krazy:exclude=foreach
+    const auto lst = Akonadi::AgentManager::self()->instances();
+    for (Akonadi::AgentInstance agent : lst) {
         agent.setIsOnline(false);
     }
 }
