@@ -32,7 +32,7 @@ class AKONADICORE_EXPORT RelationSync : public Akonadi::Job
     Q_OBJECT
 public:
     explicit RelationSync(QObject *parent = nullptr);
-    virtual ~RelationSync();
+    ~RelationSync() override;
 
     void setRemoteRelations(const Akonadi::Relation::List &relations);
 
@@ -50,8 +50,8 @@ private:
 private:
     Akonadi::Relation::List mRemoteRelations;
     Akonadi::Relation::List mLocalRelations;
-    bool mRemoteRelationsSet;
-    bool mLocalRelationsFetched;
+    bool mRemoteRelationsSet = false;
+    bool mLocalRelationsFetched = false;
 };
 
 }
