@@ -327,14 +327,15 @@ SessionPrivate::~SessionPrivate()
 
 void SessionPrivate::init(const QByteArray &id)
 {
-    qCDebug(AKONADICORE_LOG) << id;
-
     if (!id.isEmpty()) {
         sessionId = id;
     } else {
         sessionId = QCoreApplication::instance()->applicationName().toUtf8()
                     + '-' + QByteArray::number(qrand());
     }
+
+    qCDebug(AKONADICORE_LOG) << "Initializing session with ID" << id;
+
     connected = false;
     theNextTag = 2;
     jobRunning = false;
@@ -355,11 +356,7 @@ void SessionPrivate::forceReconnect()
     if (connection) {
         connection->forceReconnect();
     }
-#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
     QMetaObject::invokeMethod(mParent, [this]() { reconnect(); }, Qt::QueuedConnection);
-#else
-    QMetaObject::invokeMethod(mParent, "reconnect", Qt::QueuedConnection);
-#endif
 }
 
 Session::Session(const QByteArray &sessionId, QObject *parent)
