@@ -32,7 +32,8 @@ class QString;
 class QByteArray;
 class QThread;
 
-namespace Akonadi {
+namespace Akonadi
+{
 
 class AKONADIPRIVATE_EXPORT ExternalPartStorageTransaction
 {
@@ -58,8 +59,8 @@ class AKONADIPRIVATE_EXPORT ExternalPartStorage
 public:
     static ExternalPartStorage *self();
 
-    static QString resolveAbsolutePath(const QByteArray &filename, bool *exists = Q_NULLPTR, bool legacyFallback = true);
-    static QString resolveAbsolutePath(const QString &filename, bool *exists = Q_NULLPTR, bool legacyFallback = true);
+    static QString resolveAbsolutePath(const QByteArray &filename, bool *exists = nullptr, bool legacyFallback = true);
+    static QString resolveAbsolutePath(const QString &filename, bool *exists = nullptr, bool legacyFallback = true);
     static QByteArray updateFileNameRevision(const QByteArray &filename);
     static QByteArray nameForPartId(qint64 partId);
     static QString akonadiStoragePath();
@@ -73,8 +74,7 @@ public:
 private:
     friend class ExternalPartStorageTransaction;
 
-    struct Operation
-    {
+    struct Operation {
         enum Type {
             Create,
             Delete
@@ -95,10 +95,8 @@ private:
     bool replayTransaction(const QVector<Operation> &trx, bool commit);
     void addToTransaction(const QVector<Operation> &ops);
 
-    static ExternalPartStorage *sInstance;
-
     mutable QMutex mTransactionLock;
-    QHash<QThread*, QVector<Operation>> mTransactions;
+    QHash<QThread *, QVector<Operation>> mTransactions;
 };
 
 }
