@@ -27,7 +27,8 @@
 
 #include <QSharedDataPointer>
 
-class QString;
+#include <QString>
+class QJsonObject;
 class QStringList;
 
 namespace Akonadi
@@ -66,6 +67,8 @@ public:
         bool isEmpty() const;
         bool operator==(const HRID &other) const;
 
+        void toJson(QJsonObject &json) const;
+
         qint64 id;
         QString remoteId;
     };
@@ -110,6 +113,7 @@ public:
     QString rid() const;
     QString gid() const;
 
+    void toJson(QJsonObject &json) const;
 private:
     QSharedDataPointer<ScopePrivate> d;
     friend class ScopePrivate;
