@@ -22,17 +22,15 @@
 
 
 #include <QSettings>
-#include <QDataStream>
 #include <QEventLoop>
-#include <QGlobalStatic>
 #include <QThreadStorage>
 
 #include "storage/datastore.h"
+#include "storage/dbdeadlockcatcher.h"
 #include "handler.h"
 #include "notificationmanager.h"
 
 #include "tracer.h"
-#include "collectionreferencemanager.h"
 
 #include <cassert>
 
@@ -40,7 +38,6 @@
 #include <cxxabi.h>
 #endif
 
-#include <QElapsedTimer>
 
 #include <private/protocol_p.h>
 #include <private/datastream_p_p.h>
@@ -120,7 +117,6 @@ void Connection::quit()
     }
 
     Tracer::self()->endConnection(m_identifier, QString());
-    collectionReferenceManager()->removeSession(m_sessionId);
 
     delete m_socket;
     m_socket = nullptr;
@@ -135,7 +131,7 @@ void Connection::quit()
 
 void Connection::slotSendHello()
 {
-    SchemaVersion version = SchemaVersion::retrieveAll().first();
+    SchemaVersion version = SchemaVersion::retrieveAll().at(0);
 
     Protocol::HelloResponse hello;
     hello.setServerName(QStringLiteral("Akonadi"));
@@ -153,11 +149,6 @@ DataStore *Connection::storageBackend()
     return m_backend;
 }
 
-CollectionReferenceManager *Connection::collectionReferenceManager()
-{
-    return CollectionReferenceManager::instance();
-}
-
 Connection::~Connection()
 {
     quitThread();
@@ -194,6 +185,19 @@ void Connection::slotSocketDisconnected()
     Q_EMIT disconnected();
 }
 
+void Connection::parseStream(const Protocol::CommandPtr &cmd)
+{
+    if (!m_currentHandler->parseStream()) {
+        try {
+            m_currentHandler->failureResponse("Error while handling a command");
+        } catch (...) {
+            m_connectionClosing = true;
+        }
+        qCWarning(AKONADISERVER_LOG) << "Error while handling command" << cmd->type()
+                                     << "on connection" << m_identifier;
+    }
+}
+
 void Connection::handleIncomingData()
 {
     Q_FOREVER {
@@ -259,7 +263,7 @@ void Connection::handleIncomingData()
                 Tracer::self()->connectionInput(m_identifier, tag, cmd);
             }
 
-            m_currentHandler = std::unique_ptr<Handler>(findHandlerForCommand(cmd->type()));
+            m_currentHandler = findHandlerForCommand(cmd->type());
             if (!m_currentHandler) {
                 qCWarning(AKONADISERVER_LOG) << "Invalid command: no such handler for" << cmd->type()
                                              << "on connection" << m_identifier;
@@ -274,15 +278,7 @@ void Connection::handleIncomingData()
             m_currentHandler->setTag(tag);
             m_currentHandler->setCommand(cmd);
             try {
-                if (!m_currentHandler->parseStream()) {
-                    try {
-                        m_currentHandler->failureResponse("Error while handling a command");
-                    } catch (...) {
-                        m_connectionClosing = true;
-                    }
-                    qCWarning(AKONADISERVER_LOG) << "Error while handling command" << cmd->type()
-                                                 << "on connection" << m_identifier;
-                }
+                DbDeadlockCatcher catcher([this, &cmd]() { parseStream(cmd); });
             } catch (const Akonadi::Server::HandlerException &e) {
                 if (m_currentHandler) {
                     try {
@@ -366,9 +362,9 @@ CommandContext *Connection::context() const
     return const_cast<CommandContext *>(&m_context);
 }
 
-Handler *Connection::findHandlerForCommand(Protocol::Command::Type command)
+std::unique_ptr<Handler> Connection::findHandlerForCommand(Protocol::Command::Type command)
 {
-    Handler *handler = Handler::findHandlerForCommandAlwaysAllowed(command);
+    auto handler = Handler::findHandlerForCommandAlwaysAllowed(command);
     if (handler) {
         return handler;
     }
