@@ -45,12 +45,12 @@ public:
     explicit NotificationSubscriber(NotificationManager *manager, quintptr socketDescriptor);
     ~NotificationSubscriber();
 
-    inline QByteArray subscriber() const
+    Q_REQUIRED_RESULT inline QByteArray subscriber() const
     {
         return mSubscriber;
     }
 
-    QLocalSocket *socket() const
+    Q_REQUIRED_RESULT QLocalSocket *socket() const
     {
         return mSocket;
     }
@@ -85,6 +85,7 @@ private:
     bool isMoveDestinationResourceMonitored(const Protocol::ItemChangeNotification &msg) const;
     bool isMoveDestinationResourceMonitored(const Protocol::CollectionChangeNotification &msg) const;
 
+    Protocol::CollectionChangeNotificationPtr customizeCollection(const Protocol::CollectionChangeNotificationPtr &msg);
     Protocol::SubscriptionChangeNotificationPtr toChangeNotification() const;
 
 protected Q_SLOTS:
@@ -107,6 +108,9 @@ protected:
     QSet<QByteArray> mMonitoredResources;
     QSet<QByteArray> mIgnoredSessions;
     QByteArray mSession;
+    Protocol::ItemFetchScope mItemFetchScope;
+    Protocol::CollectionFetchScope mCollectionFetchScope;
+    Protocol::TagFetchScope mTagFetchScope;
     bool mAllMonitored;
     bool mExclusive;
     bool mNotificationDebugging;
