@@ -42,9 +42,7 @@ using namespace Akonadi::Server;
 
 PreprocessorInstance::PreprocessorInstance(const QString &id)
     : QObject()
-    , mBusy(false)
     , mId(id)
-    , mInterface(nullptr)
 {
     Q_ASSERT(!id.isEmpty());
 }
@@ -142,7 +140,7 @@ void PreprocessorInstance::processHeadItem()
     qCDebug(AKONADISERVER_LOG) << "PreprocessorInstance::processHeadItem(): processing started for item " << itemId;
 }
 
-int PreprocessorInstance::currentProcessingTime()
+qint64 PreprocessorInstance::currentProcessingTime()
 {
     if (!mBusy) {
         return -1; // nothing being processed
