@@ -30,6 +30,7 @@ namespace Akonadi
 namespace Server
 {
 
+class QueryBuilder;
 class Collection;
 
 /**
@@ -64,7 +65,12 @@ public:
 
     void invalidateCollection(const Collection &col);
 
+    void expireCache();
+
 protected:
+    explicit CollectionStatistics(bool prefetch = true);
+    QueryBuilder prepareGenericQuery();
+
     virtual Statistics calculateCollectionStatistics(const Collection &col);
 
     QMutex mCacheLock;
