@@ -44,6 +44,7 @@ using namespace std::chrono_literals;
 
 using namespace Akonadi;
 using namespace Akonadi::Server;
+using namespace AkRanges;
 
 DbConfigPostgresql::DbConfigPostgresql()
     : mHostPort(0)
@@ -127,9 +128,9 @@ QStringList DbConfigPostgresql::postgresSearchPaths(const QString &versionedPath
         qDebug() << versionedDirs;
         std::sort(versionedDirs.begin(), versionedDirs.end(), VersionCompare());
         std::reverse(versionedDirs.begin(), versionedDirs.end());
-        paths += versionedDirs | transform([](const auto &dir) -> QString {
+        paths += versionedDirs | Views::transform([](const auto &dir) -> QString {
                                     return dir.absoluteFilePath() + QStringLiteral("/bin"); })
-                               | toQList;
+                               | Actions::toQList;
     }
 
     return paths;
@@ -442,7 +443,7 @@ bool DbConfigPostgresql::startInternalServer()
         qCDebug(AKONADISERVER_LOG) << "Found a postmaster.pid pidfile, checking whether the server is still running...";
         QByteArray pid = postmaster.readLine();
         // Remove newline character
-        pid.truncate(pid.size() - 1);
+        pid.chop(1);
         QFile proc(QString::fromLatin1("/proc/" + pid + "/stat"));
         // Check whether the process with the PID from pidfile still exists and whether
         // it's actually still postgres or, whether the PID has been recycled in the
@@ -487,7 +488,7 @@ bool DbConfigPostgresql::startInternalServer()
         if (versions.has_value() && (versions->clusterVersion < versions->pgServerVersion)) {
             qCInfo(AKONADISERVER_LOG) << "Cluster PG_VERSION is" << versions->clusterVersion << ", PostgreSQL server is version " << versions->pgServerVersion << ", will attempt to upgrade the cluster";
             if (upgradeCluster(versions->clusterVersion)) {
-                qCInfo(AKONADISERVER_LOG) << "Succesfully upgraded db cluster from Postgres" << versions->clusterVersion << "to" << versions->pgServerVersion;
+                qCInfo(AKONADISERVER_LOG) << "Successfully upgraded db cluster from Postgres" << versions->clusterVersion << "to" << versions->pgServerVersion;
             } else {
                 qCWarning(AKONADISERVER_LOG) << "Postgres db cluster upgrade failed, Akonadi will fail to start. Sorry.";
             }
@@ -619,7 +620,7 @@ void DbConfigPostgresql::stopInternalServer()
 
 bool DbConfigPostgresql::checkServerIsRunning()
 {
-    const QString command = QStringLiteral("%1").arg(mServerPath);
+    const QString command = mServerPath;
     QStringList arguments;
     arguments << QStringLiteral("status")
               << QStringLiteral("--pgdata=%1").arg(mPgData);
