@@ -22,6 +22,8 @@
 
 #include "dbconfig.h"
 
+#include <shared/akoptional.h>
+
 namespace Akonadi
 {
 namespace Server
@@ -72,7 +74,18 @@ public:
      */
     void stopInternalServer() override;
 
+protected:
+    QStringList postgresSearchPaths(const QString &versionedPath) const;
+
 private:
+    struct Versions {
+        int clusterVersion = 0;
+        int pgServerVersion = 0;
+    };
+    akOptional<Versions> checkPgVersion() const;
+    bool upgradeCluster(int clusterVersion);
+    bool runInitDb(const QString &dbDataPath);
+
     bool checkServerIsRunning();
 
     QString mDatabaseName;
@@ -84,6 +97,7 @@ private:
     QString mServerPath;
     QString mInitDbPath;
     QString mPgData;
+    QString mPgUpgradePath;
     bool mInternalServer;
 };
 
