@@ -37,6 +37,12 @@ public:
     const char *type() const throw() override;
 };
 
+class DbDeadlockException : public DbException
+{
+public:
+    explicit DbDeadlockException(const QSqlQuery &query);
+};
+
 } // namespace Server
 } // namespace Akonadi
 
