@@ -41,7 +41,7 @@
 
 #include <QDomDocument>
 #include <QFile>
-#include <QTime>
+#include <QElapsedTimer>
 #include <QSqlResult>
 
 using namespace Akonadi;
@@ -154,7 +154,7 @@ bool DbUpdater::parseUpdateSets(int currentVersion, UpdateSet::Map &updates) con
 
     const QDomElement documentElement = document.documentElement();
     if (documentElement.tagName() != QLatin1String("updates")) {
-        qCCritical(AKONADISERVER_LOG) << "Invalid update description file formant";
+        qCCritical(AKONADISERVER_LOG) << "Invalid update description file format";
         return false;
     }
 
@@ -240,7 +240,7 @@ bool DbUpdater::complexUpdate_25()
 
     DbType::Type dbType = DbType::type(DataStore::self()->database());
 
-    QTime ttotal;
+    QElapsedTimer ttotal;
     ttotal.start();
 
     // Recover from possibly failed or interrupted update
