@@ -20,16 +20,16 @@
 #ifndef ENTITY_H
 #define ENTITY_H
 
-#include <QDateTime>
-#include <QDebug>
 #include <QString>
 #include <QStringList>
 
 class QVariant;
 class QSqlDatabase;
 
-namespace Akonadi {
-namespace Server {
+namespace Akonadi
+{
+namespace Server
+{
 
 /**
   Base class for classes representing database records. It also contains
@@ -50,7 +50,8 @@ public:
     template <typename T> static QString joinByName(const QVector<T> &list, const QString &sep)
     {
         QStringList tmp;
-        Q_FOREACH (const T &t, list) {
+        tmp.reserve(list.count());
+        for (const T &t : list) {
             tmp << t.name();
         }
         return tmp.join(sep);
@@ -137,7 +138,8 @@ private:
     qint64 m_id;
 };
 
-namespace _detail {
+namespace _detail
+{
 
 /*!
   Binary predicate to sort collections of Entity subclasses by
@@ -157,8 +159,7 @@ namespace _detail {
   \end
 */
 template <template <typename U> class Op>
-struct ById
-{
+struct ById {
     typedef bool result_type;
     bool operator()(Entity::Id lhs, Entity::Id rhs) const
     {
@@ -185,5 +186,4 @@ struct ById
 } // namespace Server
 } // namespace Akonadi
 
-
 #endif
