@@ -155,7 +155,7 @@ void NotificationCollector::collectionChanged(const Collection &collection,
         CollectionStatistics::self()->invalidateCollection(collection);
     }
     collectionNotification(Protocol::CollectionChangeNotification::Modify, collection, collection.parentId(),
-                           -1, resource, changes | toQSet);
+                           -1, resource, changes | AkRanges::Actions::toQSet);
 }
 
 void NotificationCollector::collectionMoved(const Collection &collection,
@@ -534,7 +534,7 @@ void NotificationCollector::completeNotification(const Protocol::ChangeNotificat
             }
 
             // FetchHelper may trigger ItemRetriever, which needs RemoteID. If we
-            // dont have one (maybe because the Resource has not stored it yet,
+            // don't have one (maybe because the Resource has not stored it yet,
             // we emit a notification without it and leave it up to the Monitor
             // to retrieve the Item on demand - we should have a RID stored in
             // Akonadi by then.
