@@ -116,7 +116,7 @@ void CollectionRequester::Private::_k_collectionsNamesReceived(KJob *job)
 void CollectionRequester::Private::init()
 {
     QHBoxLayout *hbox = new QHBoxLayout(q);
-    hbox->setMargin(0);
+    hbox->setContentsMargins(0, 0, 0, 0);
 
     edit = new QLineEdit(q);
     edit->setReadOnly(true);
@@ -161,7 +161,7 @@ void CollectionRequester::Private::_k_slotOpenDialog()
 
     const Akonadi::Collection collection = dlg->selectedCollection();
     q->setCollection(collection);
-    emit q->collectionChanged(collection);
+    Q_EMIT q->collectionChanged(collection);
 }
 
 CollectionRequester::CollectionRequester(QWidget *parent)
@@ -198,7 +198,7 @@ void CollectionRequester::setCollection(const Collection &collection)
     }
 
     d->edit->setText(name);
-    emit collectionChanged(collection);
+    Q_EMIT collectionChanged(collection);
     d->fetchCollection(collection);
 }
 
