@@ -73,6 +73,7 @@ public:
 
     void modelLoaded()
     {
+        filterRecursiveCollectionFilter->sort(0, Qt::AscendingOrder);
         collectionView->setEnabled(true);
         collectionView->expandAll();
         mOkButton->setEnabled(true);
@@ -156,6 +157,7 @@ void SubscriptionDialog::showHiddenCollection(bool showHidden)
 
 void SubscriptionDialog::init(const QStringList &mimetypes)
 {
+    setAttribute(Qt::WA_DeleteOnClose);
     setWindowTitle(i18n("Local Subscriptions"));
     QWidget *mainWidget = new QWidget(this);
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
@@ -165,9 +167,14 @@ void SubscriptionDialog::init(const QStringList &mimetypes)
 
     d->filterRecursiveCollectionFilter
         = new Akonadi::RecursiveCollectionFilterProxyModel(this);
-    d->filterRecursiveCollectionFilter->setDynamicSortFilter(true);
     d->filterRecursiveCollectionFilter->setSourceModel(d->model);
     d->filterRecursiveCollectionFilter->setFilterCaseSensitivity(Qt::CaseInsensitive);
+
+    d->filterRecursiveCollectionFilter->setSortRole(Qt::DisplayRole);
+    d->filterRecursiveCollectionFilter->setSortCaseSensitivity(Qt::CaseSensitive);
+    d->filterRecursiveCollectionFilter->setSortLocaleAware(true);
+
+
     if (!mimetypes.isEmpty()) {
         d->filterRecursiveCollectionFilter->addContentMimeTypeInclusionFilters(mimetypes);
     }
