@@ -37,15 +37,13 @@ class Q_DECL_HIDDEN TagSelectionDialog::Private
 public:
     Private(QDialog *parent)
         : d(parent)
-        , mTagWidget(nullptr)
-        , mButtonBox(nullptr)
     {
     }
     void writeConfig();
     void readConfig();
-    QDialog *d;
-    Akonadi::TagEditWidget *mTagWidget;
-    QDialogButtonBox *mButtonBox;
+    QDialog *d = nullptr;
+    Akonadi::TagEditWidget *mTagWidget = nullptr;
+    QDialogButtonBox *mButtonBox = nullptr;
 };
 
 void TagSelectionDialog::Private::writeConfig()
@@ -71,6 +69,7 @@ TagSelectionDialog::TagSelectionDialog(QWidget *parent)
     QVBoxLayout *vbox = new QVBoxLayout(this);
 
     Monitor *monitor = new Monitor(this);
+    monitor->setObjectName(QStringLiteral("TagSelectionDialogMonitor"));
     monitor->setTypeMonitored(Monitor::Tags);
 
     Akonadi::TagModel *model = new Akonadi::TagModel(monitor, this);
