@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -40,13 +40,13 @@ public:
     ~TagSelectWidget();
 
     void setSelection(const Akonadi::Tag::List &tags);
-    Akonadi::Tag::List selection() const;
+    Q_REQUIRED_RESULT Akonadi::Tag::List selection() const;
 
     /**
      * @brief tagToStringList
      * @return QStringList from selected tag (List of Url)
      */
-    QStringList tagToStringList() const;
+    Q_REQUIRED_RESULT QStringList tagToStringList() const;
     /**
      * @brief setSelectionFromStringList, convert a QStringList to Tag (converted from url)
      */
